# AgentBeats SDK

Official AgentBeats SDK for easier agent building

## Install

PYPI ver:
pip install agentbeats

TestPYPI ver:
powershell python -m pip install --index-url https://test.pypi.org/simple --extra-index-url https://pypi.org/simple agentbeats